/* valaclassregisterfunction.c generated by valac, the Vala compiler
 * generated from valaclassregisterfunction.vala, do not modify */

/* valaclassregisterfunction.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valacodegen.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <valaccode.h>
#include <vala.h>
#include <glib-object.h>
#include <valagee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_code_context_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_context_unref (var), NULL)))
#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))

static gpointer vala_class_register_function_parent_class = NULL;

static gchar* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_class_finalize_func_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_gtype_value_table_init_function_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_gtype_value_table_free_function_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_gtype_value_table_copy_function_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_gtype_value_table_collect_value_function_name (ValaTypeRegisterFunction* base);
static gchar* vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name (ValaTypeRegisterFunction* base);
static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base);
static void vala_class_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base,
                                                                           ValaCodeContext* context,
                                                                           ValaCCodeBlock* block,
                                                                           gboolean plugin);
static GType vala_class_register_function_get_type_once (void);

ValaClass*
vala_class_register_function_get_class_reference (ValaClassRegisterFunction* self)
{
	ValaClass* result;
	ValaTypeSymbol* _tmp0_;
	ValaTypeSymbol* _tmp1_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = vala_typeregister_function_get_type_symbol ((ValaTypeRegisterFunction*) self);
	_tmp1_ = _tmp0_;
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, VALA_TYPE_CLASS, ValaClass);
	return result;
}

/**
 * Creates a new C function to register the specified class at runtime.
 *
 * @param cl a class
 * @return   newly created class register function
 */
ValaClassRegisterFunction*
vala_class_register_function_construct (GType object_type,
                                        ValaClass* cl)
{
	ValaClassRegisterFunction* self = NULL;
	g_return_val_if_fail (cl != NULL, NULL);
	self = (ValaClassRegisterFunction*) vala_typeregister_function_construct (object_type, (ValaTypeSymbol*) cl);
	return self;
}

ValaClassRegisterFunction*
vala_class_register_function_new (ValaClass* cl)
{
	return vala_class_register_function_construct (VALA_TYPE_CLASS_REGISTER_FUNCTION, cl);
}

static gchar*
vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	gchar* _tmp2_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_get_ccode_type_name ((ValaObjectTypeSymbol*) _tmp1_);
	result = _tmp2_;
	return result;
}

static gchar*
vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	ValaConstructor* _tmp2_;
	ValaConstructor* _tmp3_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_class_get_class_constructor (_tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_ != NULL) {
		ValaClass* _tmp4_;
		ValaClass* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		_tmp4_ = vala_class_register_function_get_class_reference (self);
		_tmp5_ = _tmp4_;
		_tmp6_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp5_, NULL);
		_tmp7_ = _tmp6_;
		_tmp8_ = g_strdup_printf ("%s_base_init", _tmp7_);
		_tmp9_ = _tmp8_;
		_g_free0 (_tmp7_);
		result = _tmp9_;
		return result;
	} else {
		gchar* _tmp10_;
		_tmp10_ = g_strdup ("NULL");
		result = _tmp10_;
		return result;
	}
}

static gchar*
vala_class_register_function_real_get_class_finalize_func_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	ValaDestructor* _tmp2_;
	ValaDestructor* _tmp3_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_class_get_static_destructor (_tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_ != NULL) {
		ValaClass* _tmp4_;
		ValaClass* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		_tmp4_ = vala_class_register_function_get_class_reference (self);
		_tmp5_ = _tmp4_;
		_tmp6_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp5_, NULL);
		_tmp7_ = _tmp6_;
		_tmp8_ = g_strdup_printf ("%s_class_finalize", _tmp7_);
		_tmp9_ = _tmp8_;
		_g_free0 (_tmp7_);
		result = _tmp9_;
		return result;
	} else {
		gchar* _tmp10_;
		_tmp10_ = g_strdup ("NULL");
		result = _tmp10_;
		return result;
	}
}

static gchar*
vala_class_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	ValaDestructor* _tmp2_;
	ValaDestructor* _tmp3_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_class_get_class_destructor (_tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_ != NULL) {
		ValaClass* _tmp4_;
		ValaClass* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		_tmp4_ = vala_class_register_function_get_class_reference (self);
		_tmp5_ = _tmp4_;
		_tmp6_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp5_, NULL);
		_tmp7_ = _tmp6_;
		_tmp8_ = g_strdup_printf ("%s_base_finalize", _tmp7_);
		_tmp9_ = _tmp8_;
		_g_free0 (_tmp7_);
		result = _tmp9_;
		return result;
	} else {
		gchar* _tmp10_;
		_tmp10_ = g_strdup ("NULL");
		result = _tmp10_;
		return result;
	}
}

static gchar*
vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp1_, NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup_printf ("%s_class_init", _tmp3_);
	_tmp5_ = _tmp4_;
	_g_free0 (_tmp3_);
	result = _tmp5_;
	return result;
}

static gchar*
vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_get_ccode_name ((ValaCodeNode*) _tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup_printf ("sizeof (%s)", _tmp3_);
	_tmp5_ = _tmp4_;
	_g_free0 (_tmp3_);
	result = _tmp5_;
	return result;
}

static gchar*
vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp1_, NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup_printf ("%s_instance_init", _tmp3_);
	_tmp5_ = _tmp4_;
	_g_free0 (_tmp3_);
	result = _tmp5_;
	return result;
}

static gchar*
vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	ValaClass* _tmp3_;
	gchar* _tmp4_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_class_get_base_class (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = vala_get_ccode_type_id ((ValaCodeNode*) _tmp3_);
	result = _tmp4_;
	return result;
}

static gchar*
vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaClass* _tmp0_;
	ValaClass* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_class_register_function_get_class_reference (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = vala_class_get_is_abstract (_tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_) {
		gchar* _tmp4_;
		_tmp4_ = g_strdup ("G_TYPE_FLAG_ABSTRACT");
		result = _tmp4_;
		return result;
	} else {
		gboolean _tmp5_ = FALSE;
		ValaCodeContext* _tmp6_;
		ValaCodeContext* _tmp7_;
		gboolean _tmp8_;
		_tmp6_ = vala_code_context_get ();
		_tmp7_ = _tmp6_;
		_tmp8_ = vala_code_context_require_glib_version (_tmp7_, 2, 70);
		_vala_code_context_unref0 (_tmp7_);
		if (_tmp8_) {
			ValaClass* _tmp9_;
			ValaClass* _tmp10_;
			gboolean _tmp11_;
			gboolean _tmp12_;
			_tmp9_ = vala_class_register_function_get_class_reference (self);
			_tmp10_ = _tmp9_;
			_tmp11_ = vala_class_get_is_sealed (_tmp10_);
			_tmp12_ = _tmp11_;
			_tmp5_ = _tmp12_;
		} else {
			_tmp5_ = FALSE;
		}
		if (_tmp5_) {
			gchar* _tmp13_;
			_tmp13_ = g_strdup ("G_TYPE_FLAG_FINAL");
			result = _tmp13_;
			return result;
		} else {
			ValaCodeContext* _tmp14_;
			ValaCodeContext* _tmp15_;
			gboolean _tmp16_;
			_tmp14_ = vala_code_context_get ();
			_tmp15_ = _tmp14_;
			_tmp16_ = vala_code_context_require_glib_version (_tmp15_, 2, 74);
			_vala_code_context_unref0 (_tmp15_);
			if (_tmp16_) {
				gchar* _tmp17_;
				_tmp17_ = g_strdup ("G_TYPE_FLAG_NONE");
				result = _tmp17_;
				return result;
			} else {
				gchar* _tmp18_;
				_tmp18_ = g_strdup ("0");
				result = _tmp18_;
				return result;
			}
		}
	}
}

static gchar*
vala_class_register_function_real_get_gtype_value_table_init_function_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	gboolean _tmp0_ = FALSE;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_fundamental = FALSE;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp1_ = vala_class_register_function_get_class_reference (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = vala_class_get_is_compact (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		ValaClass* _tmp5_;
		ValaClass* _tmp6_;
		ValaClass* _tmp7_;
		ValaClass* _tmp8_;
		_tmp5_ = vala_class_register_function_get_class_reference (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = vala_class_get_base_class (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = _tmp8_ == NULL;
	} else {
		_tmp0_ = FALSE;
	}
	is_fundamental = _tmp0_;
	if (is_fundamental) {
		ValaClass* _tmp9_;
		ValaClass* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp9_ = vala_class_register_function_get_class_reference (self);
		_tmp10_ = _tmp9_;
		_tmp11_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp10_, "value_");
		_tmp12_ = _tmp11_;
		_tmp13_ = g_strdup_printf ("%s_init", _tmp12_);
		_tmp14_ = _tmp13_;
		_g_free0 (_tmp12_);
		result = _tmp14_;
		return result;
	}
	result = NULL;
	return result;
}

static gchar*
vala_class_register_function_real_get_gtype_value_table_free_function_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	gboolean _tmp0_ = FALSE;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_fundamental = FALSE;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp1_ = vala_class_register_function_get_class_reference (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = vala_class_get_is_compact (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		ValaClass* _tmp5_;
		ValaClass* _tmp6_;
		ValaClass* _tmp7_;
		ValaClass* _tmp8_;
		_tmp5_ = vala_class_register_function_get_class_reference (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = vala_class_get_base_class (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = _tmp8_ == NULL;
	} else {
		_tmp0_ = FALSE;
	}
	is_fundamental = _tmp0_;
	if (is_fundamental) {
		ValaClass* _tmp9_;
		ValaClass* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp9_ = vala_class_register_function_get_class_reference (self);
		_tmp10_ = _tmp9_;
		_tmp11_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp10_, "value_");
		_tmp12_ = _tmp11_;
		_tmp13_ = g_strdup_printf ("%s_free_value", _tmp12_);
		_tmp14_ = _tmp13_;
		_g_free0 (_tmp12_);
		result = _tmp14_;
		return result;
	}
	result = NULL;
	return result;
}

static gchar*
vala_class_register_function_real_get_gtype_value_table_copy_function_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	gboolean _tmp0_ = FALSE;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_fundamental = FALSE;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp1_ = vala_class_register_function_get_class_reference (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = vala_class_get_is_compact (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		ValaClass* _tmp5_;
		ValaClass* _tmp6_;
		ValaClass* _tmp7_;
		ValaClass* _tmp8_;
		_tmp5_ = vala_class_register_function_get_class_reference (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = vala_class_get_base_class (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = _tmp8_ == NULL;
	} else {
		_tmp0_ = FALSE;
	}
	is_fundamental = _tmp0_;
	if (is_fundamental) {
		ValaClass* _tmp9_;
		ValaClass* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp9_ = vala_class_register_function_get_class_reference (self);
		_tmp10_ = _tmp9_;
		_tmp11_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp10_, "value_");
		_tmp12_ = _tmp11_;
		_tmp13_ = g_strdup_printf ("%s_copy_value", _tmp12_);
		_tmp14_ = _tmp13_;
		_g_free0 (_tmp12_);
		result = _tmp14_;
		return result;
	}
	result = NULL;
	return result;
}

static gchar*
vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	gboolean _tmp0_ = FALSE;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_fundamental = FALSE;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp1_ = vala_class_register_function_get_class_reference (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = vala_class_get_is_compact (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		ValaClass* _tmp5_;
		ValaClass* _tmp6_;
		ValaClass* _tmp7_;
		ValaClass* _tmp8_;
		_tmp5_ = vala_class_register_function_get_class_reference (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = vala_class_get_base_class (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = _tmp8_ == NULL;
	} else {
		_tmp0_ = FALSE;
	}
	is_fundamental = _tmp0_;
	if (is_fundamental) {
		ValaClass* _tmp9_;
		ValaClass* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp9_ = vala_class_register_function_get_class_reference (self);
		_tmp10_ = _tmp9_;
		_tmp11_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp10_, "value_");
		_tmp12_ = _tmp11_;
		_tmp13_ = g_strdup_printf ("%s_peek_pointer", _tmp12_);
		_tmp14_ = _tmp13_;
		_g_free0 (_tmp12_);
		result = _tmp14_;
		return result;
	}
	result = NULL;
	return result;
}

static gchar*
vala_class_register_function_real_get_gtype_value_table_collect_value_function_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	gboolean _tmp0_ = FALSE;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_fundamental = FALSE;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp1_ = vala_class_register_function_get_class_reference (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = vala_class_get_is_compact (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		ValaClass* _tmp5_;
		ValaClass* _tmp6_;
		ValaClass* _tmp7_;
		ValaClass* _tmp8_;
		_tmp5_ = vala_class_register_function_get_class_reference (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = vala_class_get_base_class (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = _tmp8_ == NULL;
	} else {
		_tmp0_ = FALSE;
	}
	is_fundamental = _tmp0_;
	if (is_fundamental) {
		ValaClass* _tmp9_;
		ValaClass* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp9_ = vala_class_register_function_get_class_reference (self);
		_tmp10_ = _tmp9_;
		_tmp11_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp10_, "value_");
		_tmp12_ = _tmp11_;
		_tmp13_ = g_strdup_printf ("%s_collect_value", _tmp12_);
		_tmp14_ = _tmp13_;
		_g_free0 (_tmp12_);
		result = _tmp14_;
		return result;
	}
	result = NULL;
	return result;
}

static gchar*
vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	gboolean _tmp0_ = FALSE;
	ValaClass* _tmp1_;
	ValaClass* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_fundamental = FALSE;
	gchar* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp1_ = vala_class_register_function_get_class_reference (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = vala_class_get_is_compact (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		ValaClass* _tmp5_;
		ValaClass* _tmp6_;
		ValaClass* _tmp7_;
		ValaClass* _tmp8_;
		_tmp5_ = vala_class_register_function_get_class_reference (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = vala_class_get_base_class (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = _tmp8_ == NULL;
	} else {
		_tmp0_ = FALSE;
	}
	is_fundamental = _tmp0_;
	if (is_fundamental) {
		ValaClass* _tmp9_;
		ValaClass* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp9_ = vala_class_register_function_get_class_reference (self);
		_tmp10_ = _tmp9_;
		_tmp11_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp10_, "value_");
		_tmp12_ = _tmp11_;
		_tmp13_ = g_strdup_printf ("%s_lcopy_value", _tmp12_);
		_tmp14_ = _tmp13_;
		_g_free0 (_tmp12_);
		result = _tmp14_;
		return result;
	}
	result = NULL;
	return result;
}

static ValaCCodeFragment*
vala_class_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* base)
{
	ValaClassRegisterFunction * self;
	ValaCCodeFragment* frag = NULL;
	ValaCCodeFragment* _tmp0_;
	ValaCCodeFragment* result;
	self = (ValaClassRegisterFunction*) base;
	_tmp0_ = vala_ccode_fragment_new ();
	frag = _tmp0_;
	{
		ValaList* _base_type_list = NULL;
		ValaClass* _tmp1_;
		ValaClass* _tmp2_;
		ValaList* _tmp3_;
		gint _base_type_size = 0;
		ValaList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		gint _base_type_index = 0;
		_tmp1_ = vala_class_register_function_get_class_reference (self);
		_tmp2_ = _tmp1_;
		_tmp3_ = vala_class_get_base_types (_tmp2_);
		_base_type_list = _tmp3_;
		_tmp4_ = _base_type_list;
		_tmp5_ = vala_collection_get_size ((ValaCollection*) _tmp4_);
		_tmp6_ = _tmp5_;
		_base_type_size = _tmp6_;
		_base_type_index = -1;
		while (TRUE) {
			gint _tmp7_;
			gint _tmp8_;
			ValaDataType* base_type = NULL;
			ValaList* _tmp9_;
			gpointer _tmp10_;
			ValaDataType* _tmp11_;
			ValaTypeSymbol* _tmp12_;
			ValaTypeSymbol* _tmp13_;
			ValaInterface* iface = NULL;
			ValaDataType* _tmp14_;
			ValaTypeSymbol* _tmp15_;
			ValaTypeSymbol* _tmp16_;
			gchar* iface_info_name = NULL;
			ValaInterface* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
			gchar* _tmp21_;
			ValaCCodeDeclaration* ctypedecl = NULL;
			ValaCCodeDeclaration* _tmp22_;
			ValaCCodeDeclaration* _tmp23_;
			ValaCCodeDeclaration* _tmp24_;
			const gchar* _tmp25_;
			ValaClass* _tmp26_;
			ValaClass* _tmp27_;
			gchar* _tmp28_;
			gchar* _tmp29_;
			ValaInterface* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			gchar* _tmp33_;
			gchar* _tmp34_;
			ValaCCodeConstant* _tmp35_;
			ValaCCodeConstant* _tmp36_;
			ValaCCodeVariableDeclarator* _tmp37_;
			ValaCCodeVariableDeclarator* _tmp38_;
			ValaCCodeFragment* _tmp39_;
			ValaCCodeDeclaration* _tmp40_;
			_base_type_index = _base_type_index + 1;
			_tmp7_ = _base_type_index;
			_tmp8_ = _base_type_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _base_type_list;
			_tmp10_ = vala_list_get (_tmp9_, _base_type_index);
			base_type = (ValaDataType*) _tmp10_;
			_tmp11_ = base_type;
			_tmp12_ = vala_data_type_get_type_symbol (_tmp11_);
			_tmp13_ = _tmp12_;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, VALA_TYPE_INTERFACE)) {
				_vala_code_node_unref0 (base_type);
				continue;
			}
			_tmp14_ = base_type;
			_tmp15_ = vala_data_type_get_type_symbol (_tmp14_);
			_tmp16_ = _tmp15_;
			iface = G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, VALA_TYPE_INTERFACE, ValaInterface);
			_tmp17_ = iface;
			_tmp18_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp17_, NULL);
			_tmp19_ = _tmp18_;
			_tmp20_ = g_strdup_printf ("%s_info", _tmp19_);
			_tmp21_ = _tmp20_;
			_g_free0 (_tmp19_);
			iface_info_name = _tmp21_;
			_tmp22_ = vala_ccode_declaration_new ("const GInterfaceInfo");
			ctypedecl = _tmp22_;
			_tmp23_ = ctypedecl;
			vala_ccode_node_set_modifiers ((ValaCCodeNode*) _tmp23_, VALA_CCODE_MODIFIERS_STATIC);
			_tmp24_ = ctypedecl;
			_tmp25_ = iface_info_name;
			_tmp26_ = vala_class_register_function_get_class_reference (self);
			_tmp27_ = _tmp26_;
			_tmp28_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp27_, NULL);
			_tmp29_ = _tmp28_;
			_tmp30_ = iface;
			_tmp31_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp30_, NULL);
			_tmp32_ = _tmp31_;
			_tmp33_ = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) " \
"NULL, NULL}", _tmp29_, _tmp32_);
			_tmp34_ = _tmp33_;
			_tmp35_ = vala_ccode_constant_new (_tmp34_);
			_tmp36_ = _tmp35_;
			_tmp37_ = vala_ccode_variable_declarator_new (_tmp25_, (ValaCCodeExpression*) _tmp36_, NULL);
			_tmp38_ = _tmp37_;
			vala_ccode_declaration_add_declarator (_tmp24_, (ValaCCodeDeclarator*) _tmp38_);
			_vala_ccode_node_unref0 (_tmp38_);
			_vala_ccode_node_unref0 (_tmp36_);
			_g_free0 (_tmp34_);
			_g_free0 (_tmp32_);
			_g_free0 (_tmp29_);
			_tmp39_ = frag;
			_tmp40_ = ctypedecl;
			vala_ccode_fragment_append (_tmp39_, (ValaCCodeNode*) _tmp40_);
			_vala_ccode_node_unref0 (ctypedecl);
			_g_free0 (iface_info_name);
			_vala_code_node_unref0 (base_type);
		}
	}
	result = frag;
	return result;
}

static void
vala_class_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base,
                                                                      ValaCodeContext* context,
                                                                      ValaCCodeBlock* block,
                                                                      gboolean plugin)
{
	ValaClassRegisterFunction * self;
	ValaCodeGenerator* _tmp80_;
	ValaCodeGenerator* _tmp81_;
	ValaClass* _tmp82_;
	ValaClass* _tmp83_;
	self = (ValaClassRegisterFunction*) base;
	g_return_if_fail (context != NULL);
	g_return_if_fail (block != NULL);
	{
		ValaList* _base_type_list = NULL;
		ValaClass* _tmp0_;
		ValaClass* _tmp1_;
		ValaList* _tmp2_;
		gint _base_type_size = 0;
		ValaList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gint _base_type_index = 0;
		_tmp0_ = vala_class_register_function_get_class_reference (self);
		_tmp1_ = _tmp0_;
		_tmp2_ = vala_class_get_base_types (_tmp1_);
		_base_type_list = _tmp2_;
		_tmp3_ = _base_type_list;
		_tmp4_ = vala_collection_get_size ((ValaCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_base_type_size = _tmp5_;
		_base_type_index = -1;
		while (TRUE) {
			gint _tmp6_;
			gint _tmp7_;
			ValaDataType* base_type = NULL;
			ValaList* _tmp8_;
			gpointer _tmp9_;
			ValaDataType* _tmp10_;
			ValaTypeSymbol* _tmp11_;
			ValaTypeSymbol* _tmp12_;
			ValaInterface* iface = NULL;
			ValaDataType* _tmp13_;
			ValaTypeSymbol* _tmp14_;
			ValaTypeSymbol* _tmp15_;
			gchar* iface_info_name = NULL;
			ValaInterface* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
			_base_type_index = _base_type_index + 1;
			_tmp6_ = _base_type_index;
			_tmp7_ = _base_type_size;
			if (!(_tmp6_ < _tmp7_)) {
				break;
			}
			_tmp8_ = _base_type_list;
			_tmp9_ = vala_list_get (_tmp8_, _base_type_index);
			base_type = (ValaDataType*) _tmp9_;
			_tmp10_ = base_type;
			_tmp11_ = vala_data_type_get_type_symbol (_tmp10_);
			_tmp12_ = _tmp11_;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, VALA_TYPE_INTERFACE)) {
				_vala_code_node_unref0 (base_type);
				continue;
			}
			_tmp13_ = base_type;
			_tmp14_ = vala_data_type_get_type_symbol (_tmp13_);
			_tmp15_ = _tmp14_;
			iface = G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, VALA_TYPE_INTERFACE, ValaInterface);
			_tmp16_ = iface;
			_tmp17_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp16_, NULL);
			_tmp18_ = _tmp17_;
			_tmp19_ = g_strdup_printf ("%s_info", _tmp18_);
			_tmp20_ = _tmp19_;
			_g_free0 (_tmp18_);
			iface_info_name = _tmp20_;
			if (!plugin) {
				ValaCCodeFunctionCall* reg_call = NULL;
				ValaCCodeIdentifier* _tmp21_;
				ValaCCodeIdentifier* _tmp22_;
				ValaCCodeFunctionCall* _tmp23_;
				ValaCCodeFunctionCall* _tmp24_;
				ValaCCodeFunctionCall* _tmp25_;
				ValaClass* _tmp26_;
				ValaClass* _tmp27_;
				gchar* _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				ValaCCodeIdentifier* _tmp32_;
				ValaCCodeIdentifier* _tmp33_;
				ValaCCodeFunctionCall* _tmp34_;
				ValaInterface* _tmp35_;
				gchar* _tmp36_;
				gchar* _tmp37_;
				ValaCCodeIdentifier* _tmp38_;
				ValaCCodeIdentifier* _tmp39_;
				ValaCCodeFunctionCall* _tmp40_;
				const gchar* _tmp41_;
				gchar* _tmp42_;
				gchar* _tmp43_;
				ValaCCodeIdentifier* _tmp44_;
				ValaCCodeIdentifier* _tmp45_;
				ValaCCodeFunctionCall* _tmp46_;
				ValaCCodeExpressionStatement* _tmp47_;
				ValaCCodeExpressionStatement* _tmp48_;
				_tmp21_ = vala_ccode_identifier_new ("g_type_add_interface_static");
				_tmp22_ = _tmp21_;
				_tmp23_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp22_);
				_tmp24_ = _tmp23_;
				_vala_ccode_node_unref0 (_tmp22_);
				reg_call = _tmp24_;
				_tmp25_ = reg_call;
				_tmp26_ = vala_class_register_function_get_class_reference (self);
				_tmp27_ = _tmp26_;
				_tmp28_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp27_, NULL);
				_tmp29_ = _tmp28_;
				_tmp30_ = g_strdup_printf ("%s_type_id", _tmp29_);
				_tmp31_ = _tmp30_;
				_tmp32_ = vala_ccode_identifier_new (_tmp31_);
				_tmp33_ = _tmp32_;
				vala_ccode_function_call_add_argument (_tmp25_, (ValaCCodeExpression*) _tmp33_);
				_vala_ccode_node_unref0 (_tmp33_);
				_g_free0 (_tmp31_);
				_g_free0 (_tmp29_);
				_tmp34_ = reg_call;
				_tmp35_ = iface;
				_tmp36_ = vala_get_ccode_type_id ((ValaCodeNode*) _tmp35_);
				_tmp37_ = _tmp36_;
				_tmp38_ = vala_ccode_identifier_new (_tmp37_);
				_tmp39_ = _tmp38_;
				vala_ccode_function_call_add_argument (_tmp34_, (ValaCCodeExpression*) _tmp39_);
				_vala_ccode_node_unref0 (_tmp39_);
				_g_free0 (_tmp37_);
				_tmp40_ = reg_call;
				_tmp41_ = iface_info_name;
				_tmp42_ = g_strdup_printf ("&%s", _tmp41_);
				_tmp43_ = _tmp42_;
				_tmp44_ = vala_ccode_identifier_new (_tmp43_);
				_tmp45_ = _tmp44_;
				vala_ccode_function_call_add_argument (_tmp40_, (ValaCCodeExpression*) _tmp45_);
				_vala_ccode_node_unref0 (_tmp45_);
				_g_free0 (_tmp43_);
				_tmp46_ = reg_call;
				_tmp47_ = vala_ccode_expression_statement_new ((ValaCCodeExpression*) _tmp46_);
				_tmp48_ = _tmp47_;
				vala_ccode_block_add_statement (block, (ValaCCodeNode*) _tmp48_);
				_vala_ccode_node_unref0 (_tmp48_);
				_vala_ccode_node_unref0 (reg_call);
			} else {
				ValaCCodeFunctionCall* reg_call = NULL;
				ValaCCodeIdentifier* _tmp49_;
				ValaCCodeIdentifier* _tmp50_;
				ValaCCodeFunctionCall* _tmp51_;
				ValaCCodeFunctionCall* _tmp52_;
				ValaCCodeFunctionCall* _tmp53_;
				ValaCCodeIdentifier* _tmp54_;
				ValaCCodeIdentifier* _tmp55_;
				ValaCCodeFunctionCall* _tmp56_;
				ValaClass* _tmp57_;
				ValaClass* _tmp58_;
				gchar* _tmp59_;
				gchar* _tmp60_;
				gchar* _tmp61_;
				gchar* _tmp62_;
				ValaCCodeIdentifier* _tmp63_;
				ValaCCodeIdentifier* _tmp64_;
				ValaCCodeFunctionCall* _tmp65_;
				ValaInterface* _tmp66_;
				gchar* _tmp67_;
				gchar* _tmp68_;
				ValaCCodeIdentifier* _tmp69_;
				ValaCCodeIdentifier* _tmp70_;
				ValaCCodeFunctionCall* _tmp71_;
				const gchar* _tmp72_;
				gchar* _tmp73_;
				gchar* _tmp74_;
				ValaCCodeIdentifier* _tmp75_;
				ValaCCodeIdentifier* _tmp76_;
				ValaCCodeFunctionCall* _tmp77_;
				ValaCCodeExpressionStatement* _tmp78_;
				ValaCCodeExpressionStatement* _tmp79_;
				_tmp49_ = vala_ccode_identifier_new ("g_type_module_add_interface");
				_tmp50_ = _tmp49_;
				_tmp51_ = vala_ccode_function_call_new ((ValaCCodeExpression*) _tmp50_);
				_tmp52_ = _tmp51_;
				_vala_ccode_node_unref0 (_tmp50_);
				reg_call = _tmp52_;
				_tmp53_ = reg_call;
				_tmp54_ = vala_ccode_identifier_new ("module");
				_tmp55_ = _tmp54_;
				vala_ccode_function_call_add_argument (_tmp53_, (ValaCCodeExpression*) _tmp55_);
				_vala_ccode_node_unref0 (_tmp55_);
				_tmp56_ = reg_call;
				_tmp57_ = vala_class_register_function_get_class_reference (self);
				_tmp58_ = _tmp57_;
				_tmp59_ = vala_get_ccode_lower_case_name ((ValaCodeNode*) _tmp58_, NULL);
				_tmp60_ = _tmp59_;
				_tmp61_ = g_strdup_printf ("%s_type_id", _tmp60_);
				_tmp62_ = _tmp61_;
				_tmp63_ = vala_ccode_identifier_new (_tmp62_);
				_tmp64_ = _tmp63_;
				vala_ccode_function_call_add_argument (_tmp56_, (ValaCCodeExpression*) _tmp64_);
				_vala_ccode_node_unref0 (_tmp64_);
				_g_free0 (_tmp62_);
				_g_free0 (_tmp60_);
				_tmp65_ = reg_call;
				_tmp66_ = iface;
				_tmp67_ = vala_get_ccode_type_id ((ValaCodeNode*) _tmp66_);
				_tmp68_ = _tmp67_;
				_tmp69_ = vala_ccode_identifier_new (_tmp68_);
				_tmp70_ = _tmp69_;
				vala_ccode_function_call_add_argument (_tmp65_, (ValaCCodeExpression*) _tmp70_);
				_vala_ccode_node_unref0 (_tmp70_);
				_g_free0 (_tmp68_);
				_tmp71_ = reg_call;
				_tmp72_ = iface_info_name;
				_tmp73_ = g_strdup_printf ("&%s", _tmp72_);
				_tmp74_ = _tmp73_;
				_tmp75_ = vala_ccode_identifier_new (_tmp74_);
				_tmp76_ = _tmp75_;
				vala_ccode_function_call_add_argument (_tmp71_, (ValaCCodeExpression*) _tmp76_);
				_vala_ccode_node_unref0 (_tmp76_);
				_g_free0 (_tmp74_);
				_tmp77_ = reg_call;
				_tmp78_ = vala_ccode_expression_statement_new ((ValaCCodeExpression*) _tmp77_);
				_tmp79_ = _tmp78_;
				vala_ccode_block_add_statement (block, (ValaCCodeNode*) _tmp79_);
				_vala_ccode_node_unref0 (_tmp79_);
				_vala_ccode_node_unref0 (reg_call);
			}
			_g_free0 (iface_info_name);
			_vala_code_node_unref0 (base_type);
		}
	}
	_tmp80_ = vala_code_context_get_codegen (context);
	_tmp81_ = _tmp80_;
	_tmp82_ = vala_class_register_function_get_class_reference (self);
	_tmp83_ = _tmp82_;
	vala_ccode_base_module_register_dbus_info (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, VALA_TYPE_CCODE_BASE_MODULE, ValaCCodeBaseModule), block, (ValaObjectTypeSymbol*) _tmp83_);
}

static void
vala_class_register_function_class_init (ValaClassRegisterFunctionClass * klass,
                                         gpointer klass_data)
{
	vala_class_register_function_parent_class = g_type_class_peek_parent (klass);
	((ValaTypeRegisterFunctionClass *) klass)->get_type_struct_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_type_struct_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_base_init_func_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_base_init_func_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_class_finalize_func_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_class_finalize_func_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_base_finalize_func_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_base_finalize_func_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_class_init_func_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_class_init_func_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_instance_struct_size = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_instance_struct_size;
	((ValaTypeRegisterFunctionClass *) klass)->get_instance_init_func_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_instance_init_func_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_parent_type_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_parent_type_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_type_flags = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_type_flags;
	((ValaTypeRegisterFunctionClass *) klass)->get_gtype_value_table_init_function_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_gtype_value_table_init_function_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_gtype_value_table_free_function_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_gtype_value_table_free_function_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_gtype_value_table_copy_function_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_gtype_value_table_copy_function_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_gtype_value_table_peek_pointer_function_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_gtype_value_table_collect_value_function_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_gtype_value_table_collect_value_function_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_gtype_value_table_lcopy_value_function_name = (gchar* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name;
	((ValaTypeRegisterFunctionClass *) klass)->get_type_interface_init_declaration = (ValaCCodeFragment* (*) (ValaTypeRegisterFunction*)) vala_class_register_function_real_get_type_interface_init_declaration;
	((ValaTypeRegisterFunctionClass *) klass)->get_type_interface_init_statements = (void (*) (ValaTypeRegisterFunction*, ValaCodeContext*, ValaCCodeBlock*, gboolean)) vala_class_register_function_real_get_type_interface_init_statements;
}

static void
vala_class_register_function_instance_init (ValaClassRegisterFunction * self,
                                            gpointer klass)
{
}

/**
 * C function to register a class at runtime.
 */
static GType
vala_class_register_function_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ValaClassRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_class_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaClassRegisterFunction), 0, (GInstanceInitFunc) vala_class_register_function_instance_init, NULL };
	GType vala_class_register_function_type_id;
	vala_class_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaClassRegisterFunction", &g_define_type_info, 0);
	return vala_class_register_function_type_id;
}

GType
vala_class_register_function_get_type (void)
{
	static volatile gsize vala_class_register_function_type_id__once = 0;
	if (g_once_init_enter (&vala_class_register_function_type_id__once)) {
		GType vala_class_register_function_type_id;
		vala_class_register_function_type_id = vala_class_register_function_get_type_once ();
		g_once_init_leave (&vala_class_register_function_type_id__once, vala_class_register_function_type_id);
	}
	return vala_class_register_function_type_id__once;
}

