/* valaccodebinarycompareexpression.c generated by valac, the Vala compiler
 * generated from valaccodebinarycompareexpression.vala, do not modify */

/* valaccodebinarycompareexpression.vala
 *
 * Copyright (C) 2022  Rico Tzschichholz
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Rico Tzschichholz <ricotz@ubuntu.com>
 */

#include "valaccode.h"
#include <glib.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))

struct _ValaCCodeBinaryCompareExpressionPrivate {
	ValaCCodeExpression* _call;
	ValaCCodeExpression* _result;
};

static gint ValaCCodeBinaryCompareExpression_private_offset;
static gpointer vala_ccode_binary_compare_expression_parent_class = NULL;

static void vala_ccode_binary_compare_expression_real_write (ValaCCodeNode* base,
                                                      ValaCCodeWriter* writer);
static void vala_ccode_binary_compare_expression_finalize (ValaCCodeNode * obj);
static GType vala_ccode_binary_compare_expression_get_type_once (void);

static inline gpointer
vala_ccode_binary_compare_expression_get_instance_private (ValaCCodeBinaryCompareExpression* self)
{
	return G_STRUCT_MEMBER_P (self, ValaCCodeBinaryCompareExpression_private_offset);
}

ValaCCodeExpression*
vala_ccode_binary_compare_expression_get_call (ValaCCodeBinaryCompareExpression* self)
{
	ValaCCodeExpression* result;
	ValaCCodeExpression* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_call;
	result = _tmp0_;
	return result;
}

static gpointer
_vala_ccode_node_ref0 (gpointer self)
{
	return self ? vala_ccode_node_ref (self) : NULL;
}

void
vala_ccode_binary_compare_expression_set_call (ValaCCodeBinaryCompareExpression* self,
                                               ValaCCodeExpression* value)
{
	ValaCCodeExpression* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = _vala_ccode_node_ref0 (value);
	_vala_ccode_node_unref0 (self->priv->_call);
	self->priv->_call = _tmp0_;
}

ValaCCodeExpression*
vala_ccode_binary_compare_expression_get_result (ValaCCodeBinaryCompareExpression* self)
{
	ValaCCodeExpression* result;
	ValaCCodeExpression* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_result;
	result = _tmp0_;
	return result;
}

void
vala_ccode_binary_compare_expression_set_result (ValaCCodeBinaryCompareExpression* self,
                                                 ValaCCodeExpression* value)
{
	ValaCCodeExpression* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = _vala_ccode_node_ref0 (value);
	_vala_ccode_node_unref0 (self->priv->_result);
	self->priv->_result = _tmp0_;
}

ValaCCodeBinaryCompareExpression*
vala_ccode_binary_compare_expression_construct (GType object_type,
                                                ValaCCodeExpression* cmp,
                                                ValaCCodeBinaryOperator op,
                                                ValaCCodeExpression* l,
                                                ValaCCodeExpression* r,
                                                ValaCCodeExpression* res)
{
	ValaCCodeBinaryCompareExpression* self = NULL;
	g_return_val_if_fail (cmp != NULL, NULL);
	g_return_val_if_fail (l != NULL, NULL);
	g_return_val_if_fail (r != NULL, NULL);
	g_return_val_if_fail (res != NULL, NULL);
	self = (ValaCCodeBinaryCompareExpression*) vala_ccode_binary_expression_construct (object_type, op, l, r);
	vala_ccode_binary_compare_expression_set_call (self, cmp);
	vala_ccode_binary_compare_expression_set_result (self, res);
	return self;
}

ValaCCodeBinaryCompareExpression*
vala_ccode_binary_compare_expression_new (ValaCCodeExpression* cmp,
                                          ValaCCodeBinaryOperator op,
                                          ValaCCodeExpression* l,
                                          ValaCCodeExpression* r,
                                          ValaCCodeExpression* res)
{
	return vala_ccode_binary_compare_expression_construct (VALA_TYPE_CCODE_BINARY_COMPARE_EXPRESSION, cmp, op, l, r, res);
}

static void
vala_ccode_binary_compare_expression_real_write (ValaCCodeNode* base,
                                                 ValaCCodeWriter* writer)
{
	ValaCCodeBinaryCompareExpression * self;
	ValaCCodeExpression* _tmp0_;
	ValaCCodeExpression* _tmp1_;
	ValaCCodeExpression* _tmp2_;
	ValaCCodeExpression* _tmp3_;
	ValaCCodeExpression* _tmp4_;
	ValaCCodeBinaryOperator _tmp5_;
	ValaCCodeBinaryOperator _tmp6_;
	ValaCCodeExpression* _tmp7_;
	self = (ValaCCodeBinaryCompareExpression*) base;
	g_return_if_fail (writer != NULL);
	_tmp0_ = self->priv->_call;
	vala_ccode_expression_write_inner (_tmp0_, writer);
	vala_ccode_writer_write_string (writer, " (");
	_tmp1_ = vala_ccode_binary_expression_get_left ((ValaCCodeBinaryExpression*) self);
	_tmp2_ = _tmp1_;
	vala_ccode_node_write ((ValaCCodeNode*) _tmp2_, writer);
	vala_ccode_writer_write_string (writer, ", ");
	_tmp3_ = vala_ccode_binary_expression_get_right ((ValaCCodeBinaryExpression*) self);
	_tmp4_ = _tmp3_;
	vala_ccode_node_write ((ValaCCodeNode*) _tmp4_, writer);
	vala_ccode_writer_write_string (writer, ")");
	_tmp5_ = vala_ccode_binary_expression_get_operator ((ValaCCodeBinaryExpression*) self);
	_tmp6_ = _tmp5_;
	switch (_tmp6_) {
		case VALA_CCODE_BINARY_OPERATOR_LESS_THAN:
		{
			vala_ccode_writer_write_string (writer, " < ");
			break;
		}
		case VALA_CCODE_BINARY_OPERATOR_GREATER_THAN:
		{
			vala_ccode_writer_write_string (writer, " > ");
			break;
		}
		case VALA_CCODE_BINARY_OPERATOR_LESS_THAN_OR_EQUAL:
		{
			vala_ccode_writer_write_string (writer, " <= ");
			break;
		}
		case VALA_CCODE_BINARY_OPERATOR_GREATER_THAN_OR_EQUAL:
		{
			vala_ccode_writer_write_string (writer, " >= ");
			break;
		}
		case VALA_CCODE_BINARY_OPERATOR_EQUALITY:
		{
			vala_ccode_writer_write_string (writer, " == ");
			break;
		}
		case VALA_CCODE_BINARY_OPERATOR_INEQUALITY:
		{
			vala_ccode_writer_write_string (writer, " != ");
			break;
		}
		default:
		{
			g_assert_not_reached ();
		}
	}
	_tmp7_ = self->priv->_result;
	vala_ccode_expression_write_inner (_tmp7_, writer);
}

static void
vala_ccode_binary_compare_expression_class_init (ValaCCodeBinaryCompareExpressionClass * klass,
                                                 gpointer klass_data)
{
	vala_ccode_binary_compare_expression_parent_class = g_type_class_peek_parent (klass);
	((ValaCCodeNodeClass *) klass)->finalize = vala_ccode_binary_compare_expression_finalize;
	g_type_class_adjust_private_offset (klass, &ValaCCodeBinaryCompareExpression_private_offset);
	((ValaCCodeNodeClass *) klass)->write = (void (*) (ValaCCodeNode*, ValaCCodeWriter*)) vala_ccode_binary_compare_expression_real_write;
}

static void
vala_ccode_binary_compare_expression_instance_init (ValaCCodeBinaryCompareExpression * self,
                                                    gpointer klass)
{
	self->priv = vala_ccode_binary_compare_expression_get_instance_private (self);
}

static void
vala_ccode_binary_compare_expression_finalize (ValaCCodeNode * obj)
{
	ValaCCodeBinaryCompareExpression * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, VALA_TYPE_CCODE_BINARY_COMPARE_EXPRESSION, ValaCCodeBinaryCompareExpression);
	_vala_ccode_node_unref0 (self->priv->_call);
	_vala_ccode_node_unref0 (self->priv->_result);
	VALA_CCODE_NODE_CLASS (vala_ccode_binary_compare_expression_parent_class)->finalize (obj);
}

/**
 * Represents an expression comparing two operands checking against a non-boolean result in C code.
 */
static GType
vala_ccode_binary_compare_expression_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeBinaryCompareExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_binary_compare_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeBinaryCompareExpression), 0, (GInstanceInitFunc) vala_ccode_binary_compare_expression_instance_init, NULL };
	GType vala_ccode_binary_compare_expression_type_id;
	vala_ccode_binary_compare_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_BINARY_EXPRESSION, "ValaCCodeBinaryCompareExpression", &g_define_type_info, 0);
	ValaCCodeBinaryCompareExpression_private_offset = g_type_add_instance_private (vala_ccode_binary_compare_expression_type_id, sizeof (ValaCCodeBinaryCompareExpressionPrivate));
	return vala_ccode_binary_compare_expression_type_id;
}

GType
vala_ccode_binary_compare_expression_get_type (void)
{
	static volatile gsize vala_ccode_binary_compare_expression_type_id__once = 0;
	if (g_once_init_enter (&vala_ccode_binary_compare_expression_type_id__once)) {
		GType vala_ccode_binary_compare_expression_type_id;
		vala_ccode_binary_compare_expression_type_id = vala_ccode_binary_compare_expression_get_type_once ();
		g_once_init_leave (&vala_ccode_binary_compare_expression_type_id__once, vala_ccode_binary_compare_expression_type_id);
	}
	return vala_ccode_binary_compare_expression_type_id__once;
}

